==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
            a.ad("MultiColumnComboBoxValueChangedEventArgs", () => new MultiColumnComboBoxValueChangedEventArgsDescription());
            a.ac("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
            a.ae("MultiColumnComboBoxValueChangedEventArgs", () => new MultiColumnComboBoxValueChangedEventArgsDescription());
            a.ad("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
})();
